function out = defineStandardEventCodes
% Event-codes used to synchronize behavioral (Matlab) and
% neurophysiology hardware follow a convention in which the first four pins
% are reserved to represent the same events, irrespective of the hardware
% or experiment.
% This function defines the decimals that reflect this convention, as they
% are specified in the table below:
% 
% 'trlMtch' is not defined in this function because its corresponding
% decimals are generated with the sendEvent function.
%
% | decimal | binary    | NAME      | meaning                                           |
% | ------- | ------    |------     |---------------------------------------------------|
% | 0       | 0000      | reset     | set all pins to zero                              |
% | 1       | 0001      | itiOn     | start of the trial                                |
% | 2       | 0010      | stimOn    | any stimulus on: auditory/ visual/ neural ...)    |
% | 3       | 0011      | off       | anything off: stimulus/ reward/ punishment ...)   |
% | 4       | 0100      | bhv       | any behavior: peck/ fixation/ location ...)       |
% | 5       | 0101      | rwd       | reward on                                         |
% | 6       | 0110      | pun       | punishiment on                                    |
% | 7       | 0111      | end       | trial end                                         |
% | 8-15    | 1000-1111 | trlMtch   | A fail safe to match data. A randomNumber (8:15)  |
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR 
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% This function is called in myParadigmSetup 
%
% Author: Sara 
% Version: 1.1
% Date: 30.08.2021
%
% 15.10.2021, Sara : - added 'reset' to standard events. 
% 25.03.2022, Tobias: removed computations that are done in initOTBR

%%
global SETUP

SETUP.events.stdEvents.reset    = 0;
SETUP.events.stdEvents.itiOn    = 1;
SETUP.events.stdEvents.stimOn   = 2;
SETUP.events.stdEvents.off      = 3;
SETUP.events.stdEvents.bhv      = 4;
SETUP.events.stdEvents.rwd      = 5;
SETUP.events.stdEvents.pun      = 6;
SETUP.events.stdEvents.end      = 7;

out = SETUP;


end