function sendNetworkBoxEvents(num)
% Use this function only for "NetworkBox" hardware with firmware version 3.4 or higher!
% Otherwise, events may not be sent or may not be automatically reset as predicted.
%
% When using this function events are sent using the defined pins in myHardwareSetup.m in section 3c
% The event pins are automatically reset after 500us and it is not necessary to turn them on and of
% as it was before.
%
% This function has only one argument and that is the event number that is sent via the event pins.
% Currently, there is no input validation or other checks for performance reasons. 
% Please check yourself if the passed events are meaningful and can be represented!
%
% Usage: sendNetworkBoxEvents(num)

% Tobias Otto
% 1.0
% 17.10.2023

% 17.10.2023, Tobias: first draft

%% Init variables
global SETUP

%% Split input into pins
binVec = rem(floor((num) ./ SETUP.events.powersOf2), 2);

%% Send events using bIO code
pnet(SETUP.networkDIO.obj, 'write', uint32([8 SETUP.events.pins binVec]), 'intel');
pnet(SETUP.networkDIO.obj, 'writepacket');