function startMRIExample
% This is a simple example program that shows how to use the OTBR toolbox in an MRI experiment and
% what possibilities there are.
%
% This example experiment starts the program TriggerCounter, which takes care of capturing the
% triggers. The configuration of the TriggerCounter is done via the configuration file
% myHardwareSetup.m.
%
% This version of the Triggercounter program detects trigger when the t key is pressed. So programs
% % can be tested easily, especially the dummy scans!
% Before the example program starts, the key t must be pressed three times, because in this example
% three dummy scans must be considered.

% Tobias Otto
% 1.0
% 24.11.2012

% 24.11.2012, Tobias: first draft

%% Init toolbox and experiment
initOTBR;
startExperiment;    % Not necessary for human experiments yet, but it doesn't hurt

%% Init variables
% We recommend to initialize all variables in this section and to program constantly with
% variables. This makes changes (changing presentation times, etc.) easier and this would be the
% only place where changes have to be done.

% Init variables
p.subject       = inputdlg({'Subject'});
p.stimPres      = 10;                       % Stimulus presentation time in seconds
p.fixCross1     = 10;                       % Time in seconds for first and last fixation cross
p.fixCross2     = 5;                        % Time in seconds for ITI
p.instr         = 10;                       % Time in seconds for the instructions

p.numTrials     = 5;

p.dummyScans    = 3;                        % Number of dummy scans before the actual experiment starts


% Get some technical detials
p.savePath    	= [pwd '\Result\'];
p.stimuli       = [pwd '\Stimuli\'];
p.info          = getBasicInformation;
p.info2         = 'This is a simple example program that shows how to use the OTBR toolbox in an MRI experiment.';

%% Init MRI part 1
p.mmap = initMRIChatPart1;

%%
try
    %% Init screen and load stimuli
    % Init screen
    initWindow(2);

    % Load images and randomize
    im(1)   = loadImage([p.stimuli 'h1.jpg']);
    im(2)   = loadImage([p.stimuli 'h2.jpg']);
    im(3)   = loadImage([p.stimuli 'h3.jpg']);
    im(4)   = loadImage([p.stimuli 'h4.jpg']);
    im(5)   = loadImage([p.stimuli 'h5.jpg']);
    im      = im(randperm(5));

    %% Init MRT part 2 and save start time
    p.startTime = initMRIChatPart2(p.mmap, p.dummyScans);

    %% Show instructions
    showInstructions('instructions.txt', 'noKey');
    r.instr.time        = GetSecs;          % Save the time when the instructions were presented
    r.instr.triggers    = p.mmap.Data(1);   % Save the number of triggers as well

    % Wait
    WaitSecs(p.instr);

    %% Present first fixation cross
    fixationCross(0);
    r.fixCross1.time        = GetSecs;
    r.fixCross1.triggers    = p.mmap.Data(1);

    % Wait
    WaitSecs(p.fixCross1);

    %% Start main loop
    for i=1:p.numTrials
        %% Show image
        showStimuli(im(i));
        r.stimulus(i).time      = GetSecs;
        r.stimulus(i).triggers  = p.mmap.Data(1);
        r.stimulus(i).name      = im(i).filename;

        % Wait
        WaitSecs(p.stimPres);

        %% Show fixation cross
        fixationCross(0);
        r.fixCross2(i).time     = GetSecs;
        r.fixCross2(i).triggers = p.mmap.Data(1);

        % Wait
        WaitSecs(p.fixCross2);
    end

    %% Present last fixation cross
    fixationCross(0);
    r.fixCross3.time        = GetSecs;
    r.fixCross3.triggers    = p.mmap.Data(1);

    % Wait
    WaitSecs(p.fixCross1);

    %% Save data and clean up
    % Save data
    save2File(p, r, 'subject', p.subject{1}, 'path', p.savePath);

    % Close presentation window and show user info to close triggerCounter
    stopExperiment;

catch
    closeWindow;
    errorSave;
end

