% This is a simple example showing the use of multiple monitors with OTBR Toolbox.
% The main monitor can be used as usual. The extra monitors can currently only display images.

% Tobias Otto
% 1.0
% 07.04.2021

% 07.04.2021, Tobias: first draft

%% Init toolbox
initOTBR

%% Init variables
monitorA = 1;
monitorB = 2;

%% Init screens and load images
try
    initWindow(monitorB);          % Main Screen on monitor 3
    initExtraWindow(monitorA);     % Main Screen on monitor 2
    
    % load stimuli
    im1 = loadImage('.\Stimuli\im1.png');
    im2 = loadImage('.\Stimuli\im2.png');
    im3 = loadImage('.\Stimuli\im3.png');
    im4 = loadImage('.\Stimuli\im4.png');
    
    %% Show two stimuli - as simple as possible
    showStimuli(im1, 1);                % Stimulus 1 on position 1
    showExtraStimuli(im2, monitorA)     % Stimulus 2 on extra screen (see help showExtraStimuli for more info)
    
    WaitSecs(3);
    
    %% Show more stimuli - more complex
    % Present two stimuli on main screen
    % First stimulus with position as argument
    showStimuli(im1, 1, 'dontFlip');                % Stimulus 1 on position 1
    % Second stimulus freely positioned
    showStimuli(im2, 'x', 10, 'y', 80);
    
    % Present two stimuli on extra screen
    showExtraStimuli(im3, monitorA, 'x', 50, 'y', 75, 'dontFlip');
    showExtraStimuli(im4, monitorA, 'x', 70, 'y', 10);
    
    WaitSecs(3);
    
    %% Clean up
    closeExtraWindow(monitorA);
    closeWindow;
    
catch
    closeWindow;
    errorSave;
end