function simpleRating_Keyboard
% This is a very simple example program of a rating experiment where subjects have to rate images.
% Rating is done with a keyboard using keys 1 to 4.

% Tobias Otto
% 1.0
% 16.11.2021

% 16.01.2021, Tobias: first draft

try
    initOTBR;
    startExperiment;    % Not necessary for human experiments yet, but it doesn't hurt

    %% Init variables
    % We recommend to initialize all variables in this section and to program constantly with
    % variables. This makes changes (changing presentation times, etc.) easier and this would be the
    % only place where changes have to be done.

    % Init variables
    p.subject       = inputdlg({'Subject'});
    p.fixCross1     = 5;    % Time in seconds for the first fixation cross
    p.fixCross2     = 1;    % Time in seconds for fixation cross in loop
    p.ansTime       = 5;    % Time in seconds for subject to answer

    p.ansKey(1)     = 49;
    p.ansKey(2)     = 50;
    p.ansKey(3)     = 51;
    p.ansKey(4)     = 52;

    p.scaleText     =  {'Yes\n1', '2', '3', 'No\n4'};

    % Get some technical detials
    p.savePath    	= [pwd '\Result\'];
    p.stimuli       = [pwd '\Stimuli\'];
    p.info          = getBasicInformation;
    p.info2         = 'This is a simple example program of a rating experiment where subjects have to rate images';

    %% Init screen
    initWindow;

    %% Load and randomize images
    % Get all stimuli
    f = dir([p.stimuli '*.jpg']);

    % Load all stimuli we found
    for i=1:length(f)
        im(i) = loadImage([p.stimuli f(i).name]);
    end

    % Randomize images
    index   = randperm(length(im));
    im      = im(index);

    %% Show instructions and first fixation cross
    % Show instructions from a text file
    showInstructions('instrKey.txt');

    % Show first fixation cross
    fixationCross(p.fixCross1);

    %% Start main loop with experiment
    for i=1:length(im)
        % Present text
        showText('Do you like this image?', 'y', 10, 'dontflip');

        % Present image
        showStimuli(im(i), 'dontflip');

        % Finally present scale
        plotScale(p.ansTime, p.scaleText, 'y', 80, 'width', 50, 'inactive');

        % Get subject answer
        r.ans(i) = getAnswer(p.ansTime, 'goodKey', p.ansKey);

        % Present fixation Cross
        fixationCross(p.fixCross2);

        % Save variables for analysis
        r.stim{i}   = im(i).filename;
        r.rt(i)     = r.ans(i).time;
    end

    %% Compute some values for feedback
    % Mean RT
    r.meanRT = mean(r.rt);

    % Find most liked image
    ansNum      = [r.ans.keyVal]-48;        % This is easy in this case ;)
    ansCount    = histcounts(ansNum);       % get hist counts
    ansMax      = max(ansCount);            % Compute max value
    r.ansLike   = find(ansCount==ansMax);   % Find the best answer

    % User info
    disp('-------------------------------------')
    disp(['Your mean reaction time was: ' num2str(r.meanRT)]);
    disp(['You liked key(s):' p.ansKey(r.ansLike) ' the most.']);

    %% Save all we have
    save2File(p, r, 'subject', p.subject{1}, 'path', p.savePath);

    %% Clean up
    stopExperiment;

catch
    closeWindow;
    errorSave;
end

