function autoshaping
% Example paradigm for the OTBR Toolbox on Windows
% Make sure to define the screen befor you start this example:
% par.screenNum	= 0;
% 0 = one screen only
% 1 = first windows screen
% 2 = second windows screen

% Tobias Otto
% 1.0
% 11.03.2021

% 11.03.2021, Tobias: first draft

%% Init toolbox
initOTBR;

%% Init variables for paradigm
par.screenNum	= 2;    % 0 = one screen only | 1= first screen | 2 = second screen
par.subject   	= 'ThisIsJustATest';

par.numTrials 	= 10;
par.iti       	= 3;    % Iti in seconds
par.feeding   	= 2;    % Feeding time in seconds
par.ansTime   	= 4;    % Time in seconds to answer
par.numPecks  	= 1;    % Number of pecks needed
par.stimPos    	= 5;    % Position of stimulus (Positions are defined in myParadigmSetup.m)

par.savePath  	= fullfile(pwd, 'Result');
par.imPath      = fullfile(pwd, 'Stimuli');

% Technical information
par.info        = getBasicInformation;
par.infoText    = 'Example autoshaping program';

%% Start loop
try
    %% Init toolbox
    initWindow(par.screenNum);
    
    %% Load stimuli
    im = loadImage(fullfile(par.imPath, 'stim1.png'));
    
    %% Start main loop
    % turn off all devices, clear screen and turn on the house light
    startExperiment;
    
    % Start loop
    for i=1:par.numTrials
        %% Start ITI
        showStimuli;
        WaitSecs(par.iti);
        
        %% Show stimulus
        showStimuli(im, par.stimPos);
        
        %% Wait for an answer
        % Save response to get performance
        out(i).ans = keyBuffer(par.ansTime, 'goodKey', par.stimPos, par.numPecks);
        
        %% Start feeding
        feeding(par.feeding);
    end
    
    %% Clean up and save
    % Close window and cleans up
    stopExperiment
    
    % Save
    save2File(par, out, 'subject', par.subject, 'path', par.savePath)
    
    % User info
    res = [out.ans];
    disp(['Performance of subject ' par.subject ': ' num2str(sum([res.goodKey])/par.numTrials*100) '%']);
    
catch
    closeWindow;
    errorSave;
end

