function [res] = bIO(pinNr, status)

% function [] = bIO(pinNr, status)
%
% Implements the communication with a udp DIO device (e.g. ODROID)
%
% requires the following filed in myHardwareSetup
%   SETUP.udpDIO.odroidIP   = '192.168.1.13';
%   SETUP.udpDIO.odroidPort = 5005;
%   SETUP.udpDIO.localPort  = 5005;
%   SETUP.udpDIO.initPins   = bin2dec('00000100'); % feeder 1 is off
%   SETUP.udpDIO.currPins   = bin2dec('00000100');
%   SETUP.udpDIO.ctrlWord   = 0;
%
% BUGS/ TODO:
% untested DRAFT
% - so far supports only writing values to pins
% - check if the host is available
% - let the shaping of the word happen ahead in mySetup?
% - add bIO(0)
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% VERSION HISTORY:
% Jonas Rose
% 1.1
% 03.03.2018

% xx.xx.2016, Jonas: first draft
% 03.03.2018, Tobias: added toolbox related init to be compatible to old code


global SETUP

res = [];

%% Check initialization
if(SETUP.networkDIO.initDone == 0)
    openNetworkIO;
end

%% check if the communication is initialized
if ~isfield(SETUP.udpDIO,'obj') || SETUP.udpDIO.obj<0

    % make sure the device-adress is given
    if ~isfield(SETUP.udpDIO, 'odroidIP') || ...
            ~isfield(SETUP.udpDIO, 'odroidPort') || ...
            ~isfield(SETUP.udpDIO, 'localPort') || ...
            isempty(SETUP.udpDIO.odroidIP) || ...
            isempty(SETUP.udpDIO.odroidPort) || ...
            isempty(SETUP.udpDIO.localPort)
        error('You need to check odroid IP, port and localport in mySetup')
    end

    % connect to odroid
    SETUP.udpDIO.obj = pnet('udpsocket',SETUP.udpDIO.localPort);
    pnet(SETUP.udpDIO.obj,'udpconnect',SETUP.udpDIO.odroidIP, SETUP.udpDIO.odroidPort);

    % start communication by sending pin values (defalut turning all off)
    pnet(SETUP.udpDIO.obj, 'write',...
        uint32([0 bin2dec(SETUP.udpDIO.initPins) 0]),'intel');
    pnet(SETUP.udpDIO.obj, 'writepacket');
    SETUP.udpDIO.currPins = SETUP.udpDIO.initPins;
end


if pinNr==0
    % send the word (this might be faster if the type casting happens somewhere else)
    pnet(SETUP.udpDIO.obj, 'write', ...
        uint32([0 bin2dec(SETUP.udpDIO.initPins) 0]),'intel');
    pnet(SETUP.udpDIO.obj, 'writepacket');
    SETUP.udpDIO.currPins = SETUP.udpDIO.initPins;
    return
end

%% write to pins
if nargin>1
    % old pin status
    pins = SETUP.udpDIO.currPins(end:-1:1);
    for i=1:length(pinNr)
        pins(pinNr(i)) = num2str(~status(i));
    end
    SETUP.udpDIO.currPins = pins(end:-1:1);
    % Send data
    pnet(SETUP.udpDIO.obj, 'write', ...
        uint32([0 bin2dec(SETUP.udpDIO.currPins) 0]), 'intel');
    pnet(SETUP.udpDIO.obj, 'writepacket');
else
    res = getTouch(pinNr);
end

