function close8PortRelay
% Use this function to close and clear the communication between the 8 port
% relay card and the computer
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also:  init8PortRelay, bIO

% VERSION HISTORY:
% Author:         Tobias Otto
% Version:        0.2
% Last Change:    14.07.2011

% 28.02.2011, Tobias: first draft
% 14.07.2011, Tobias: cleaning available bytes fom ralais card

%% Init variables
global SERIAL8PORT

%% Clean bytes available buffer
while(SERIAL8PORT.s.BytesAvailable ~= 0)
    fread(SERIAL8PORT.s, SERIAL8PORT.s.BytesAvailable,'uint8');
end

%% Close device
if(SERIAL8PORT.initDone == 1)
    disp('Deleting 8 port relay card context ...');
    fclose(SERIAL8PORT.s);
    delete(SERIAL8PORT.s);
    SERIAL8PORT.initDone = 0;
    disp(' done');
else
    disp('Nothing to do. Please init 8 port relay card first');
end

