function out = getTime(set2Zero)
% Use this function to get the time in ms from the network device!
% Caution: The time 'flips' after XXX minutes and starts from zero again.
%
% Calling setTime with an optional argument resets the time and it starts
% from zero again! Use with caution.
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also: initNetworkIO, closeNetworkIO

% VERSION HISTORY:
% Author:         Tobias Otto
% Version:        1.0
% Last Change:    05.06.2015

% 05.06.2015, Tobias: first draft

%% Init variables
global SETUP
out         = 0;
siz2Read    = 0;

%% Check initialization
if(~isfield(SETUP,'networkDIO') || SETUP.networkDIO.initDone == 0)
    initNetworkIO;
end

%% Get or reset time
if(nargin == 1)
    word = uint32(1);  % one means set time to zero
    % send data to Odroid
    pnet(SETUP.networkDIO.obj, 'write', word, 'intel');
    pnet(SETUP.networkDIO.obj, 'writepacket');
end

%% Get time anyway
word = uint32(3);    % three means get time
% send data to Odroid
pnet(SETUP.networkDIO.obj, 'write', word, 'intel');
pnet(SETUP.networkDIO.obj, 'writepacket');

% Get time from server anyway
while(siz2Read == 0)
    siz2Read = pnet(SETUP.networkDIO.obj, 'readpacket','uint32', 'noblock');
end
dat = pnet(SETUP.networkDIO.obj, 'read', siz2Read, 'uint32', 'intel', 'view', 'noblock');

out = dat;
