function callback_manualShaping

% function [] = callback_manualShaping()
%
% This function is used check if key *f* is pressed for manual shaping. If
% key *f* is pressed reward is given as long as the key is pressed.
% Please keep in mind that this function works with a low priotity. Delays
% of 50ms should be expected.
%
% EXAMPLES
% 1.
%   Don't call this function directly !
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also: initWindow, showStimuli, mySetup

% VERSION HISTORY:
% Author:         Tobias Otto
% Version:        1.3
% Last Change:    01.03.2018
%
% 11.02.2009, Tobias: Release version
% 16.03.2010, Tobias: bugfix for case that more than one feeder is used
% 15.07.2016, Tobias: cosmetics and deleted some variables
% 01.03.2018, Tobias: even more cosmetics for IKN Toolbox

%% Init variables and get access to the SETUP struct
global SETUP
len = length(SETUP.io.feeder);

%% Get keyboard status
[~, ~, keyCode] = KbCheck;

%% Does someone press the key and there is no reward?
% keyCode 70 means f for food in psych toolbox language
if(keyCode(70) == 1 && SETUP.manualShaping.reward == 0)
    SETUP.manualShaping.reward = 1;
    bIO(SETUP.io.feeder,ones(1,len));
end

if(keyCode(70) == 0 && SETUP.manualShaping.reward == 1)
    SETUP.manualShaping.reward = 0;
    bIO(SETUP.io.feeder,zeros(1,len));
end

