function out = getButtonClick(stopTime, varargin)
% Get the click on a button that was created with createButton
% Input is first the time and then a vector of button handles
%
% Usage: out = getButtonClick(time, varargin)
%
% Example: out = getButtonClick(5, bHand1, bHand2, bHand3);
% Waits 5 seconds or until a click on any of the buttons occurs
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.1
% 19.11.2009

% 19.11.2009, Tobias: First draft
% 23.11.2009, Tobias: returns out.clickPos=0 in case of no click

%% Init variables
global WINDOW
len         = length(varargin);
buttons     = [0 0 0];
escape      = 0;
escapeKey   = 27;
keyIsDown   = 0;
secs        = 0;
keyCode     = zeros(1,256);
buttonRect  = reshape(cell2mat(varargin),4,len)';
startTime   = 0;
clickPos    = 0;

%% Waiting for a button, ESC or the time
startTime   = GetSecs;
stopTime    = startTime+stopTime;

while(all(~buttons) && stopTime >= GetSecs)
    [x,y,buttons] = GetMouse(WINDOW.handle);

    [keyIsDown, secs, keyCode] = KbCheck;

    if(keyCode(escapeKey) ~= 0)
        escape = 1;
        break;
    end
end

%% Waiting for release
while(any(buttons) && escape == 0)
    [buttons(1),buttons(2),buttons] = GetMouse;

    [keyIsDown, secs, keyCode] = KbCheck;

    if(keyCode(escapeKey) ~= 0)
        escape = 1;
        break;
    end
end
stopTime = GetSecs;

%% Get Position of click and return button number
clickPos = find(x >= buttonRect(:,1) & x <= buttonRect(:,3) & ...
    y >= buttonRect(:,2) & y <= buttonRect(:,4),1);

if(isempty(clickPos))
    clickPos = 0;
end

%% Compute output struct
out.clickPos    = clickPos;
out.time        = stopTime - startTime;
out.escape      = escape;