function rebootRaspberry(host)
% This is a helper function that reboots the Raspberry without a valid connection in MATLAB or
% Octave. Call this function with a valid IP address from the Raspberry you want to reboot or use a
% handle that was created from connect2Host.
% In any case: this is the last option youi should use to reboot a Raspberry :)
%
% Usage:rebootRaspberry(host)
%
% Example: rebootRaspberry('192.168.0.50');  % Reboots Raspbery with IP 192.168.0.50
%
% Example: rebootRaspberry(h);  % Reboots Raspbery which handle is stored in h
%
% This function calls plink.exe an external program from the PuTTY MSI installer distribution.
% See http://www.chiark.greenend.org.uk/~sgtatham/putty/ for more details!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.3
% 11.05.2021
%
% 18.05.2018, Tobias: first draft
% 07.05.2021, Tobias: more user info
% 10.05.2021, Tobias: allowing Raspberry ID
% 11.05.2021, Tobias: using correct IP now

%% Init variables
global SETUP

if(~ischar(host))
    host = SETUP.raspberry.host(h).host;
end

disp(['Rebooting your remote system ' host ' the hard way ...']);

% Force reboot by connectin via SSH
cmd = sprintf('%s\\Network\\ControlComputer\\plink.exe -ssh pi@%s -pw raspberry sudo reboot', ...
    SETUP.toolboxPath, host);
try
    system(cmd);
    WaitSecs(0.2);
    disp(' ... done!');
end
