function shutdownRaspberry(host)
% This is a helper function that shuts down the Raspberry without a valid connection in MATLAB or
% Octave. Call this function with a valid IP address from the Raspberry you want to reboot or use a
% handle that was created from connect2Host.
% In any case: this is the last option youi should use to shutdown a Raspberry :)
%
% Usage:shutdownRaspberry(host)
%
% Example: shutdownRaspberry('192.168.0.50');  % Reboots Raspbery with IP 192.168.0.50
%
% Example: shutdownRaspberry(h);  % Reboots Raspbery which handle is stored in h
%
% This function calls plink.exe an external program from the PuTTY MSI installer distribution.
% See http://www.chiark.greenend.org.uk/~sgtatham/putty/ for more details!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.1
% 02.05.2022
%
% 11.05.2021, Tobias: first draft
% 02.05.2022, Tobias: replaced wrong variable

%% Init variables
global SETUP

if(~ischar(host))
    host = SETUP.raspberry.host(host).host;
end

disp(['Shutting down your remote system ' host ' the hard way ...']);

% Force reboot by connectin via SSH
cmd = sprintf('%s\\Network\\ControlComputer\\plink.exe -ssh pi@%s -pw raspberry  sudo shutdown -h now', ...
    SETUP.toolboxPath, host);
try
    system(cmd);
    WaitSecs(0.2);
    disp(' ... done!');
end
