function out = stopRemoteKeyBuffer(h)
% Use this function to stop the execution of keyBuffer on a remote
% computer. A valid network connection is required!
% This function needs the handle returned from connect2Host as input
% argument;
%
% Usage: stopRemoteKeyBuffer(handle);
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.

% Tobias Otto
% 1.2
% 05.03.2018

% 07.12.2017, Tobias: first draft
% 03.03.2018, Tobias: ip addresses and handles now in SETUP struct
% 05.03.2018, Tobias: no user info on success, only warning on error

%% Init variables
global SETUP
out     = 0;
data    = [];

%% Stop execution
% Send stop signal to remote computer
pnet(SETUP.raspberry.host(h).con, 'write', int8(31));

%% Wait for second handshake information
time = GetSecs+2;
while(isempty(data) && GetSecs < time)
    data = pnet(SETUP.raspberry.host(h).con, 'read', 1, 'int8');
end

if(data == 32)
    out = 1;
    %disp(['Stopped keyBuffer in machine : ' SETUP.raspberry.host(h).host ' successfully !']);
else
    warning('Couldn''t stop remote keybuffer :(');
end