function out = wait4NetworkResponse(time2wait)
% This function needs one input argument and a valid network
% connection to at least one remote client.
% This function waits the given time or until one client responded.
%
% Usage: out = wait4NetworkResponse(time2wait)
%
% The output is a struct that contains the following information
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.

% Tobias Otto, Jonas Rose
% 1.1
% 03.03.2018

% 08.12.2017, Tobias: first draft
% 03.03.2018, Tobias: ip addresses and handles now in SETUP struct

%% Init variables
global SETUP
data = [];

%% Get valid connections
j = 1;
for i=1:SETUP.raspberry.num
    if(SETUP.raspberry.host(i).active == 1)
        val(j)  = SETUP.raspberry.host(i);
        j       = j + 1;
    end
end

% How much do we have
len = length(val);

%% Start main loop
startTime   = GetSecs;
stopTime    = startTime + time2wait;

while(stopTime > GetSecs && isempty(data))
    % Check each network connection for a reply
    for i=1:len
        data = pnet(val(i).con, 'read', 1, 'int8');
        if(~isempty(data))
            break;
        end
    end
end

%% Copy data to output struct
out.netID   = data;
out.time    = GetSecs - startTime;

%% Empty buffer in case others responded as well
while(~isempty(data))
    data = pnet(val(i).con, 'read', 1, 'double');
end
