function sendKeyBufferResult(dat)
% This function returns the result of a keyBuffer call to the remote control
% computer. Only the most important results of the keyBuffer call are
% returned:
% goodKey, badKey, neutralKey, rt, definedGoodKey, ....
%
% This function expects the result struct of a keyBuffer call as argument!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.2
% 26.04.2018

% 04.12.2017, Tobias: first draft
% 21.03.2018, Tobias: bugfix for more than one good/bad key
% 26.04.2018, Tobias: added definedGood/Bad/neutral keys

%% Init variables
global NETWORK
global SETUP
% siz     = size(dat.raw,1);

%% First signal type of data
% Either we return data from a switchBuffer or a touchBuffer
if(SETUP.touchScreen.on == 1)
    % Data from touchBuffer
    type = 21;
else
    % Data from switchBuffer
    type = 22;
end

% Send data to indicate that the keyBuffer result will follow
pnet(NETWORK.con, 'write', type);

%% Send data for both types
% Protokoll is:
% - 1: send type
% - 2: size of data for good key followed by good key data
% - 3: size of data for bad key followed by bad key data
% - 4: size of data for neutral key followed by neutral key data
% - 5: Reaction time
% - 6: size of data for defined good key followed by good key data
% - 7: size of data for defined bad key followed by bad key data
% - 8: size of data for defined neutral key followed by neutral key data
% - 9: size of data for raw key followed by raw data

% 1 - Data type
data    = type;
% 2 - Good key
data    = [data size(dat.goodKey, 2), dat.goodKey];
% 3 - Bad key
data    = [data, size(dat.badKey, 2), dat.badKey];
% 4 - Neutral key
data    = [data, size(dat.neutralKey, 2), dat.neutralKey];
% 5 - Reaction time
data    = [data, dat.rt];
% 6 - Defined good key
data    = [data size(dat.definedGoodKey, 2), dat.definedGoodKey];
% 7 - Defined bad key
data    = [data, size(dat.definedBadKey, 2), dat.definedBadKey];
% 8 - Defined neutral key
data    = [data, size(dat.definedNeutralKey, 2), dat.definedNeutralKey];
% 9 - Raw data
siz     = size(dat.raw,1);
data    = [data, siz, reshape(dat.raw, [1 2*siz])];

% Finally send data
pnet(NETWORK.con, 'write', data);

%% Send data from touchBuffer
if(type == 21)
    % First global values, then the local values
    pnet(NETWORK.con, 'write', ...
        reshape(dat.globalValue, [1 3*siz]));
    pnet(NETWORK.con, 'write', ...
        reshape(dat.localValue, [1 3*siz]));
end
