function cameracontrol(cameras, varargin)
% Record up to 8 ip cameras with matlab
% More cameras is easily possible with copy/paste
% Argument cameras is a cell array with every ip as a string in a single
% cell and can be predefined or put in as an argument
% Preview is 1 or 0 if the matlab preview window should be opened
% Function assumes that login is admin and password 1234 so change it to
% that or change the function accordingly
% Warning: File sizes tend to get very big so video compression with a
% program like Handbrake is recommended
%
% INPUTS
%   * cameras           : ip adresses of your IP cameras
%
% INPUTS-OPTIONAL
%   * 1 or 0            : preview of the cameras (1) or not (0) in a MATLAB
%                       : window. This code changes the default settings
%                       : of 'DefaultFigureWindowStyle' for the current
%                       : session!!!
%
% EXAMPLES
% 1.
%   cameracontrol(cameras,1)
%   Opens the IP adresses saved in the cameras variable and previews them
% 2.
%   cameracontrol({'192.168.0.172','192.168.0.173','192.168.0.156'})
%   Opens the given IP adresses and a figure with the start/stop recording
%   buttons but does not preview the feed of the cameras
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023).
%               https://doi.org/10.3758/s13428-023-02199-x
%

% VERSION HISTORY:
% Author:               Robert Willma
% Version:              1.1
% Last Change:          22.10.2024
% 21.06.2024: code finished (v1.0)
% 22.10.2024: added comments (v1.1)

%% open cameras
set(0,'DefaultFigureWindowStyle','docked')
for i = 1:size(cameras,2)
    cam(i) = ipcam(strcat('http://',cameras{i},'/mjpg/video.mjpg'), 'admin', '1234');
    if numel(varargin) == 1 && varargin{1} == 1
        preview(cam(i));
    end
end

%% save Video of all cameras
start_button = uicontrol(...
    "Style","pushbutton", ...
    "String","Start Recording", ...
    "Position",[100 100 150 25], ...
    "Callback",@startrecording);
stop_button = uicontrol(...
    "Style","togglebutton", ...
    "String","Stop Recording", ...
    "Position",[100 50 150 25]);

vidWriter = cell(1,size(cameras,2));

% open VideoWriter objects and save them in the vidWriter variable
% a cell array filled with VideoWriter objects cannot change its size
% dynamically, so I did it manually for up to 8
    function startrecording(~,~)
        disp('Started Recording');
        if size(cameras,2) > 0
            vidWriter{1} = VideoWriter(sprintf('%s.avi',cameras{1}));
            open(vidWriter{1});
        end
        if size(cameras,2) > 1
            vidWriter{2} = VideoWriter(sprintf('%s.avi',cameras{2}));
            open(vidWriter{2});
        end
        if size(cameras,2) > 2
            vidWriter{3} = VideoWriter(sprintf('%s.avi',cameras{3}));
            open(vidWriter{3});
        end
        if size(cameras,2) > 3
            vidWriter{4} = VideoWriter(sprintf('%s.avi',cameras{4}));
            open(vidWriter{4});
        end
        if size(cameras,2) > 4
            vidWriter{5} = VideoWriter(sprintf('%s.avi',cameras{5}));
            open(vidWriter{5});
        end
        if size(cameras,2) > 5
            vidWriter{6} = VideoWriter(sprintf('%s.avi',cameras{6}));
            open(vidWriter{6});
        end
        if size(cameras,2) > 6
            vidWriter{7} = VideoWriter(sprintf('%s.avi',cameras{7}));
            open(vidWriter{7});
        end
        if size(cameras,2) > 7
            vidWriter{8} = VideoWriter(sprintf('%s.avi',cameras{8}));
            open(vidWriter{8});
        end

        tic
        minute_counter = 0;
        while 1
            % run the recording process until the stop button is pressed
            % this records every time this loop finishes and a frame is
            % available. Thus, the resulting video will be sped up because
            % I do not control for the runtime of the function or desired
            % frames per second. Using the embedded timestamp, it is
            % possible to calculate the factor by which the video is sped
            % up.
            if size(cameras,2) > 0
                [Image,ts] = snapshot(cam(1));
                % save a snapshot and the timestamp of the current output
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                % insert the timestamp onto the snapshot in the top left
                writeVideo(vidWriter{1}, Image_with_ts);
                % write the snapshot with the timestamp into the video
                % writer object and append it into an .avi file
            end
            if size(cameras,2) > 1
                [Image,ts] = snapshot(cam(2));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{2}, Image_with_ts);
            end
            if size(cameras,2) > 2
                [Image,ts] = snapshot(cam(3));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{3}, Image_with_ts);
            end
            if size(cameras,2) > 3
                [Image,ts] = snapshot(cam(4));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{4}, Image_with_ts);
            end
            if size(cameras,2) > 4
                [Image,ts] = snapshot(cam(5));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{5}, Image_with_ts);
            end
            if size(cameras,2) > 5
                [Image,ts] = snapshot(cam(6));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{6}, Image_with_ts);
            end
            if size(cameras,2) > 6
                [Image,ts] = snapshot(cam(7));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{7}, Image_with_ts);
            end
            if size(cameras,2) > 7
                [Image,ts] = snapshot(cam(8));
                Image_with_ts = insertText(Image,[0 0],datestr(ts, 'dd-mm-yyyy HH:MM:SS.FFF'));
                writeVideo(vidWriter{8}, Image_with_ts);
            end
            if toc > 5*60
                minute_counter = minute_counter + 5;
                fprintf('Recorded for %d minutes\n', minute_counter);
                % give feedback every 5 minutes of the recording length
                tic
            end
            if stop_button.Value == 1
                stop_button.Value = 0;
                disp('Stopped Recording');
                try
                    close(vidWriter{1});
                    close(vidWriter{2});
                    close(vidWriter{3});
                    close(vidWriter{4});
                    close(vidWriter{5});
                    close(vidWriter{6});
                    close(vidWriter{7});
                    close(vidWriter{8});
                end
                break;
                % if the stop button is pressed, close all video Writer
                % objects and stop the while loop
            end
        end
    end
end