function changeTextSettings(size, spacing)
% Use this function to change the text size and the spacing between two
% text lines on the stimulus presentation window.
% Settings are global settings until this function is called again.
% Default settings are:
%       size        = 35
%       spacing     = 1.4
%
% Usage: changeTextSettings(size, spacing)
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.0.1
% 11.05.2010

% 04.05.2010, Tobias: first draft
% 11.05.2010, Tobias: typo in help

%% Init variables
global WINDOW

%% Change settings
if(exist('size','var') && ~isempty(size))
    WINDOW.textSize = size;
    Screen('TextSize', WINDOW.handle, WINDOW.textSize);
elseif(exist('spacing','var') && ~isempty(spacing))
    WINDOW.textSpacing  = spacing;
end
