function [out, lines] = computeRealTextBounds(in)
% Similar to the Screen Textbounds function this function computes the
% "almost" real text bounds of a given text with line breaks
%
% Returns the size of the text bounds ans number of single lines
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.0
% 13.03.2017

% 13.03.2017, Tobias: first draft

%% Init variables
global WINDOW;
lines = 1;

%% Get size from original textBound function
siz = Screen('TextBounds', WINDOW.handle, in);

%% Count number of line breaks
% Get number of new lines
strPos = strfind(in, '\n');
if(~isempty(strPos))
    lines = length(strPos)+1;
end

%% Get max size of single strings (every line)
index = [-1 strPos length(in)+1];
for i=1:lines
    %disp(in(index(i)+2:index(i+1)-1));
    len(i,:) = Screen('TextBounds', WINDOW.handle, in(index(i)+2:index(i+1)-1));
end
% Get maximum for width in pixel
maxWidth = max(len(:,3));

%% Compute output
% The space between two lines is unfortunately only a rough guess
out = round([0 0 maxWidth lines*siz(4)]);