function plotQuestionnaireTable(text, ansText, topText, trial, answer)
% This function handles all the plotting for the questionnaire
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.2
% 03.03.2020

% 07.03.2017, Tobias: first draft
% 13.03.2017, Tobias: added option topText
% 03.03.2020, Tobias: added automatic fix for bad text bounds computation

%% Init variables
global WINDOW
global LASTCLICKINQUESTIONNAIRE

%% Plot answer
if(nargin == 5)
    % Compute rect for answer
    ansRect = [trial.allVertDiv(answer.index), trial.mainRect(2), trial.allVertDiv(answer.index+1), trial.mainRect(4)];
    Screen('FillRect', WINDOW.handle, trial.colorUL, ansRect);
end

if(LASTCLICKINQUESTIONNAIRE > 0)
    % Compute rect for answer
    ansRect = [trial.allVertDiv(LASTCLICKINQUESTIONNAIRE), trial.upperRect(2), trial.allVertDiv(LASTCLICKINQUESTIONNAIRE+1), trial.upperRect(4)];
    Screen('FillRect', WINDOW.handle, trial.colorUL/2, ansRect);
end

%% Draw boxes
% Main quesion box
Screen('FrameRect', WINDOW.handle, trial.color, trial.mainRect, trial.penMain);
% Vertival - main division
Screen('DrawLine', WINDOW.handle, trial.color, trial.mainVertLine(1), trial.mainVertLine(2), trial.mainVertLine(3), trial.mainVertLine(4), trial.penMain);

% Upper question box
Screen('FrameRect', WINDOW.handle, trial.colorUL, trial.upperRect, trial.penUL);
% Lower question box
Screen('FrameRect', WINDOW.handle, trial.colorUL, trial.lowerRect, trial.penUL);
% Vertical line
Screen('DrawLine', WINDOW.handle, trial.colorUL, trial.ulVertLine(1), trial.ulVertLine(2), trial.ulVertLine(3), trial.ulVertLine(4), trial.penUL);

% Plot vertical answer devisions
for i=1:trial.numAnswers-1
    % Upper and lower divisions (main included, but will be overwritten)
    Screen('DrawLine', WINDOW.handle, trial.colorUL, trial.ulAnsDiv(1,i), trial.ulAnsDiv(2,i), trial.ulAnsDiv(3,i), trial.ulAnsDiv(4,i), trial.penUL);
    % Main divisions
    Screen('DrawLine', WINDOW.handle, trial.color, trial.mainAnsDiv(1,i), trial.mainAnsDiv(2,i), trial.mainAnsDiv(3,i), trial.mainAnsDiv(4,i), trial.penMain);
end

%% Draw text
% Change text size
Screen('TextSize',WINDOW.handle ,trial.fontQuest);

% Correcting vSPacing if renderer can't compute text bounds correctly
if(trial.textBoundsBad == 1)
    vSpacing = 1.5;
else
    vSpacing = [];
end

% Draw main text
DrawFormattedText(WINDOW.handle, text{2}, 'center', 'center', trial.color, [], [], [], vSpacing, [], trial.mainQuestText);%'justifytomax'
% Draw upper text
DrawFormattedText(WINDOW.handle, text{1}, 'center', 'center', trial.colorUL, [], [], [], vSpacing, [], trial.upperQuestText);
% Draw lower text
DrawFormattedText(WINDOW.handle, text{3}, 'center', 'center', trial.colorUL, [], [], [], vSpacing, [], trial.lowerQuestText);
% Plot topText
DrawFormattedText(WINDOW.handle, topText, 'center', 'center', trial.color, [], [], [], vSpacing, [], trial.topTextPos);

% Change text size
Screen('TextSize',WINDOW.handle ,trial.fontAnsOpt);
% Plot answer text on top of frame
for i=1:trial.numAnswers
    DrawFormattedText(WINDOW.handle, ansText{i}, 'center', 'center', trial.color, [], [], [], vSpacing, [], trial.mainAnsText(i,:));
end

%% Flip
Screen('Flip', WINDOW.handle);
