function out = startQuestionnaireTable(trial, text, ansText, topText)
% This is the main function for plotting tables that are used in the
% questionnaires.
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.5
% 03.03.2020

% 07.03.2017, Tobias: first draft
% 08.03.2017, Tobias: tables changes with text size
% 09.03.2017, Tobias: fix in computation of answer text position
% 13.03.2017, Tobias: fix in computing number of line breaks in text for answers added topText option
% 26.02.2020, Tobias: added optional row height
% 03.03.2020, Tobias: added automatic fix for bad text bounds computation

%% Init variables
global WINDOW;
trial.textBoundsBad = 0;    % Helper to indicate that textbounds work well or not

%% Prepare questionnaire
% Text for questions
% Change text size for scale, conserve the old size
Screen('TextSize',WINDOW.handle ,trial.fontQuest);
% Compute text height for one line of text (nothing else possible in PsychToolbox
[~, ~, trial.fontQuestPixel] = Screen('TextBounds', WINDOW.handle, text{1});

% Use default text heigh in case the renderer returns 0 as text height
if(trial.fontQuestPixel == 0)
    trial.fontQuestPixel    = round(WINDOW.textSize*1.5);
    trial.textBoundsBad     = 1;
end

% Compute height for every text ---> look for \n
for i=1:3
    if(trial.rowHeight == 0)
        tmp = find(strfind(text{i}, '\n'));
        if(~isempty(tmp))
            trial.heightText(i) = (length(tmp)+1)*trial.fontQuestPixel;
        else
            trial.heightText(i) = trial.fontQuestPixel;
        end
        % Add factor
        %trial.heightText(i) = round(trial.heightText(i)*1.4);
    else
        % Height is defined by user!
        trial.heightText(i) = trial.rowHeight;
    end
end

% Text for answers
% Change text size for scale, conserve the old size
Screen('TextSize',WINDOW.handle ,trial.fontAnsOpt);
% Compute text height for one line of text (nothing else possible in PsychToolbox
[~, ~, trial.fontAnsOptPixel] = Screen('TextBounds', WINDOW.handle, ansText{1});

% Use default value in case the renderer returns 0 as text height
if(trial.fontAnsOptPixel == 0)
    trial.fontAnsOptPixel   = round(trial.fontAnsOpt*2);
    trial.textBoundsBad     = 1;
end

% Compute height for every text ---> look for \n
for i=1:length(ansText)
    tmp = find(strfind(ansText{i}, '\n'));
    if(~isempty(tmp))
        trial.heightAnsOpt(i) = (length(tmp)+1)*trial.fontAnsOptPixel;
    else
        trial.heightAnsOpt(i) = trial.fontAnsOptPixel;
    end
    % Add factor
    trial.heightAnsOpt(i) = round(trial.heightAnsOpt(i));
end

% only use the biggest value
trial.heightAnsOpt = max(trial.heightAnsOpt);

%% Compute measures
trial.posX    = round(trial.startX/100*WINDOW.rect(3));
trial.posY    = round(trial.startY/100*WINDOW.rect(4));
trial.width   = round((trial.stopX - trial.startX)/100*WINDOW.rect(3));

% Compute start and stop points for main horizontal lines
% Compute points for main rect
trial.mainRect	= [trial.posX trial.posY-trial.heightText(2)/2 trial.posX+trial.width trial.posY+trial.heightText(2)/2];
trial.upperRect	= [trial.posX trial.posY-trial.heightText(2)/2-trial.heightText(1) trial.posX+trial.width trial.posY-trial.heightText(2)/2];
trial.lowerRect	= [trial.posX trial.posY+trial.heightText(2)/2 trial.posX+trial.width trial.posY+trial.heightText(2)/2+trial.heightText(3)];

% Compute start and stop points for main vertical division
trial.mainVertLine	= [trial.posX+trial.mainDivision*trial.width trial.posY-trial.heightText(2)/2 trial.posX+trial.mainDivision*trial.width trial.posY+trial.heightText(2)/2];
trial.ulVertLine	= [trial.posX+trial.mainDivision*trial.width trial.posY-trial.heightText(2)/2-trial.heightText(1) trial.posX+trial.mainDivision*trial.width trial.posY+trial.heightText(2)/2+trial.heightText(3)];

% Compute divisions for answer fields
ansWidth            = round(trial.width*(trial.mainDivision) : trial.width*(1-trial.mainDivision)/trial.numAnswers : trial.width);
trial.ansWidth      = ansWidth(2:end-1);
trial.allVertDiv	= trial.posX+ansWidth;

for i=1:trial.numAnswers-1
    trial.mainAnsDiv(:,:,:,:,i)	= [trial.posX+trial.ansWidth(i) trial.posY-trial.heightText(2)/2 trial.posX+trial.ansWidth(i) trial.posY+trial.heightText(2)/2];
    trial.ulAnsDiv(:,:,:,:,i)  	= [trial.posX+trial.ansWidth(i) trial.posY-trial.heightText(2)/2-trial.heightText(1) trial.posX+trial.ansWidth(i) trial.posY+trial.heightText(2)/2+trial.heightText(3)];
end

%% Compute position of text
% Compute box for main question
trial.mainQuestText     = [3+trial.posX trial.posY-trial.heightText(2)/2 round(trial.posX+trial.width*trial.mainDivision) trial.posY+trial.heightText(2)/2];
trial.upperQuestText    = [3+trial.posX trial.posY-trial.heightText(2)/2-trial.heightText(1) round(trial.posX+trial.width*trial.mainDivision) trial.posY-trial.heightText(2)/2];
trial.lowerQuestText    = [3+trial.posX trial.posY+trial.heightText(2)/2 round(trial.posX+trial.width*trial.mainDivision) trial.posY+trial.heightText(2)/2+trial.heightText(3)];

% Compute boxes for answer fields on top of the frame!
for i=1:trial.numAnswers
    trial.mainAnsText(i,:) = [trial.posX+ansWidth(i) trial.posY-trial.heightText(2)/2-trial.heightText(1)-trial.heightAnsOpt trial.posX+ansWidth(i+1) trial.posY-trial.heightText(2)/2-trial.heightText(1)];
end

% Compute position for topText -> same height as answer text
trial.topTextPos = [3+trial.posX trial.posY-trial.heightText(2)/2-trial.heightText(1)-trial.heightAnsOpt round(trial.posX+trial.width*trial.mainDivision) trial.posY-trial.heightText(2)/2-trial.heightText(1)];

%% Plot
plotQuestionnaireTable(text, ansText, topText, trial);

%% Wait for an answer
% More variables to be initialized
startT      = GetSecs;
tmpT        = 0;
duration    = Inf;
out.escape  = 0;
minX        = trial.posX + ansWidth(1);
maxX        = trial.posX + ansWidth(end);

% Get user click
while(tmpT < duration && out.escape == 0)
    out = getMousePos(duration-tmpT);
    % Are we in the range? Fine
    if( out.y > trial.mainVertLine(2) && out.y < trial.mainVertLine(4) && ...
            out.x > minX && out.x < maxX)
        tmpT = inf;
    else
        tmpT = GetSecs-startT;
    end
end

%% Create output struct
% Compute user answer in range from 0-> left to 1-> right
out.click = (out.x-minX)/(maxX-minX);

% Compute position index
out.index	= find(out.x > trial.posX+ansWidth, 1, 'last');

% More user info
out.question    = text{2};
out.answer      = ansText{out.index};

%% Plot and mark answer
plotQuestionnaireTable(text, ansText, topText, trial, out);


