function cleanFontConfigCache
% This function cleans the font config cache of gstreamer
% Call this function if text rendering takes a very long time!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% Usage: cleanFontConfigCache

% Tobias Otto
% 1.0
% 10.01.2019

% 10.01.2019, Tobias: first draft

%% Init variables
cachePath = [getenv('HOMEDRIVE') getenv('HOMEPATH') '\AppData\Local\fontconfig\cache'];

%% User interaction
disp(' ==================================================================');
disp(' = This function cleans the font config cache of gstreamer        =');
disp(' = This is necessary if rendering text takes a very long time!    =');
disp(' =                                                                =');
disp(' = Please keep in mind that the first call of a text renderer     =');
disp(' = will again take some time, because the cache is rebuild!       =');
disp(' = Rebuilding the cache is a one time thing and the delay should  =');
disp(' = disappear afterwards.                                          =');
disp(' ==================================================================');
disp(' ');
disp(' Press y to clean font config cache stored in:');
disp(cachePath);
disp(' ');
answer = input('Press ''y'' if you want to delete the cache or ''n'' to abort: ', 's');

if(lower(answer) == 'y')
    if(exist(cachePath, 'dir'))
        system(['del /S /F /Q ' cachePath '\*']);
        disp('Done!');
    else
        disp(' --> The folder doesn''t exist on your system')
    end
else
    disp(' --> Deleting aborted!');
end

