% srcipt errorSave()
%
% This function is used to warn the user that something went wrong in a
% program. It should be called from within a catch-statement where it opens
% an error-warning and saves all workspace variables so that no data is
% lost. The workspace is saved to the file ErrorTermination_jjjjmmddhhmm.mat
% in the working directory.
%
% EXAMPLES
% 1.
%   try
%       % this is where your entire paradigm happens
%       error('test error')
%   catch
%       bioErrorSave
%   end
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also:  error

% VERSION HISTORY:
% Author:         Tobias Otto, Jonas Rose
% Version:        1.1
% Last Change:    07.06.2018
%
% 06.06.2018, Tobias: first draft based on bioErrorSave
% 07.06.2018, Tobias: save in Octave needs extra parameter to be compatible with MATLAB

%% BUGS/ TODO
% - no known bugs

%% Get last error
errorMessage = lasterror;

%% Save everything we have in workspace
tmp	= ['ErrorTermination_' datestr(now, 'YYYYmmDDHHMMSS') '.mat'];
if(strfind(lower(computer), 'pcwin'))
    save(tmp);
elseif(strfind(lower(computer), 'arm'))
    save(tmp, '-v7');
end

%% User info
msg = ['There was an error executing this program. Workspace and error details are saved in ' tmp];
msgbox(msg,'Error','error');

%% Help user to identify error
disp(' ------------------------------------------------------------------')
disp(' Please check the following files for errors:');
disp(' This is a detailed output of the saved error message.');
disp(' It lists the involved functions for this error.');
disp(' ');
for i=length(errorMessage.stack):-1:1
    disp(errorMessage.stack(i))
end
disp(' ------------------------------------------------------------------')

%% Let caller function throw out the error message
rethrow(errorMessage)