function trial = getBasicInformation
% Use this function to save basic information about the experimental
% computer, the user and the date and time when the experiment was started
%
% This function returns a struct!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.3
% 06.02.2019

% 06.04.2017, Tobias: first draft
% 28.02.2018, Tobias: dbStack wrong during live editor execution
% 06.02.2019, Tobias: added try/catch for call to getCode (needed for Raspberry in network mode)

%% Get basic computer information
trial.date    	= clock;
trial.username	= getenv('USERNAME');
trial.computer 	= getenv('COMPUTERNAME');
trial.time    	= datestr(now, 'YYYYmmDDHHMMSS'); % Date and time as string

%% Get information about experiment
tmpStack        = dbstack;
go              = 1;

% Check if we run in editor live mode
for i=1:length(tmpStack)
    if(strcmpi(tmpStack(i).name, 'LiveEditorEvaluationHelperESectionEval'))
        go = 0;
        break;
    end
end

trial.dbStack = tmpStack;

if(go == 1)
    trial.fctName = trial.dbStack(end).file;
    try
        trial.fctCode = getCode(trial.fctName);
    catch
        trial.fctCode = 'Couldn''t get the code of the function, sorry!';
    end
else
    trial.fctName   = 'live editor execution';
    trial.fctCode   = 'live editor execution';
end
