function getKeyValue
% Use this function to get the key values used for getAnswer.
% Simply start program and follow instructions
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Tobias Otto
% 1.5
% 11.04.2015

% 23.02.2010, Tobias: release
% 07.05.2010, Tobias: using KBCheck again for compatibility reasons
% 16.02.2015, Tobias: added condition in case a key got "stuck" in memory
% 20.04.2015, Tobias: plotting all values for special keys (Strg, Alt)
% 18.08.2015, Tobias: optimized condition in case a key got "stuck" in memory
% 11.04.2016, Tobias: more info to problematic keys

%% Init variables
keyCode             = zeros(1,256);
keyIsDown           = 0;
tmpDouble           = 0;
tmpChar             = 0;

%% Wait until all keys are released
% Or wait at least 2 seconds ..
keyIsDown = 1;
tmp = GetSecs+2;
while(keyIsDown == 1 && GetSecs<tmp)
    % Read from keyboard
    [keyIsDown, ~, keyCode] = KbCheck;
    drawnow;
end

%% Additional info in case the keyIsDown variable is still 0
[keyIsDown, ~, keyCode] = KbCheck;
if(keyIsDown == 1)
    disp(' **************************************************************************');
    disp(' Do you experience problems with a "stuck key"? Try DisableKeysForKbCheck');
    disp(' See help DisableKeysForKbCheck for more information');
    disp(' Possible keys that could cause a problem on this machine are:');
    disp([' ' num2str(find(keyCode))]);
    disp(' **************************************************************************');
end

%% Go and wait for a button press
keyIsDown = 0;
disp('Press a key to get the key value');
while(keyIsDown == 0)
    % Read from keyboard
    [keyIsDown, ~, keyCode] = KbCheck;
end

%% Convert
tmpDouble = find(keyCode);

if(length(tmpDouble) > 1)
    disp(' **************************************************************');
    disp(' This key might give problems in your program, because it is a ');
    disp(' special character for Windows systems.')
    disp(' It''s worth a try, but you might want to use another key');
    disp(' **************************************************************');
end
tmpChar = lower(char(tmpDouble));

disp(['The keyValue for character: "' tmpChar '" is: ' num2str(tmpDouble)])

