function startTime = initMRIChatPart2(mmap, scans2Wait)
% Init MRI functions part 2
% Includes waiting for the first trigger
% Needs handle to memory mapped file and number of scans to wait as input
% arguments.
%
% Usage: startTime = initMRIChatPart2(mmap, scans2Wait)
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also: initMRIChatPart1

% Tobias Otto
% 1.2
% 24.02.2021

% 29.05.2019, Tobias: first draft based on MRTChatPart1
% 19.10.2020, Tobias: moved global struct globalAnswer to SETUP
% 24.02.2021, Tobias: return start time as optional output

%% Init variables
global SETUP

%% Wait for triggers
if(SETUP.MRI.saveTrigger == 1)
    showText('Please start MRI - waiting for triggers');
    SETUP.MRI.ScanBeforeWait = mmap.Data(1);
    SETUP.MRI.beforeLoop     = GetSecs;
    waitScan                    = mmap.Data(1) + scans2Wait;
    tmp                         = mmap.Data(1) + 1;
    % Wait !!!
    while(waitScan > mmap.Data(1))
        if(tmp == mmap.Data(1))
            tmp = 99;
            showStimuli;
        end
    end
else
    showText('Demo or programming mode!');
    WaitSecs(1);
    showStimuli;
end

%% Save and return
startTime           = GetSecs;      % Time where iti occurs
SETUP.MRI.startTime	= GetSecs;      % Time where iti occurs
SETUP.MRI.startMRT 	= mmap.Data(1);	% Number of valid scans that are already done
SETUP.MRI.startScan	= mmap.Data(2);	% Time when the last valid scan occured
