function command = printCmd(output, command, varargin)
% function cmd = printCmd(output, cmd, varargin)
%
% Use this function to assemble commands for sending to remote client.
% INPUTS
% outupt    : function output (empty or one variable name)
% command   : name of the (remote) function
% varargin  : inputs to the (remote) function can be string, or numeric
%           : (scalar or vector) cell, struct, matrix are not supported
%
% EXAMPLES:
% 1.
% printCmd([], 'keyBuffer', 10, 'goodkey', (1:3), 'badkey', 4)
%   ans = '[] = keyBuffer(10, goodkey, [1  2  3], badkey, 4);'
%
% 2.
% printCmd('result', 'keyBuffer', 10, 'goodkey', (1:3), 'badkey', 4)
%   ans = '[result] =keyBuffer(10, goodkey, [1  2  3], badkey, 4);'
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Version   1.1
% Date      12.03.2018
% Author    Jonas
%
% 08.03.2018: Jonas : first draft
% 12.03.2018: Jonas : bugfix

%% Check output variable
if isempty(output)
    command = strcat(command, '(');
else
    command = strcat(output, '=', command, '(');
end

%% add commands
for i=1:length(varargin)
    if all(ischar(varargin{i}))                                 %
        command = [command, varargin{i}, ', '];
    elseif all(size(varargin{i})==1)
        command = [command, num2str(varargin{i}), ', '];        % scalar
    elseif (size(varargin{i},1)>1) && (size(varargin{i},2)==1)  % column
        command = [command, '[', num2str(varargin{i}'), ']'', '];
    elseif (size(varargin{i},2)>1) && (size(varargin{i},1)==1)  % row
        command = [command, '[', num2str(varargin{i}), '], '];
    else
        error('printCmd cannot handle cells, structs or matrixes.');
    end
end

command = strcat(command(1:end-2), ');');
