function stopExperiment
% Use this function to "clean up" after your experiment is done.
% This function closes the stimulus presentation window and takes care of
% all stimulus devices that are used (feeder, etc)!
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also:  start, initToolbox, initWindow

% Tobias Otto
% 1.5
% 17.11.2021

% 17.07.2017, Tobias: first draft
% 01.03.2018, Tobias: added timer check and delete all timers!
% 15.03.2018, Tobias: cosmetics
% 26.03.2019, Tobias: renamed function (old name is still valid)
% 08.09.2021, Tobias: closing sound
% 17.11.2021, Tobias: added showCursor just in case

%% Init variables
global SETUP
global WINDOW

%% Close stimulus presentation window
closeWindow;
ShowCursor; % Just in case it's hidden

%% Check devices
% Turn on house light, if defined
if(~isempty(SETUP.io.houseLight))
    bIO(SETUP.io.houseLight, 1);
end

% Turn off feeder power, if defined
if(~isempty(SETUP.io.feederPower))
    bIO(SETUP.io.feederPower,zeros(1,length(SETUP.io.feederPower)));
end

%% Close connection to IO box (if necessary)
if(ismember(SETUP.io.interfaceNum, [7 8 10]))
    % Network IO - Pnet - Odroid
    % Network IO - Instrument control toolbox - Odroid
    % Network IO ACN - Pnet - Odroid
    closeNetworkIO;
end

%% Turn off sound
if(SETUP.sound.enable == 1)
    closeSound;
end

%% Find timers, stop and delete them (Windows only)
if(SETUP.platformNum == 1)
    % Find timers
    t = timerfind;

    % Delete timers
    if(~(isempty(t)))
        stop(t);
        delete(t);
        disp('--> Deleted all timer objects');
    end
end

%% User info - Trigger counter
if(~isempty(SETUP.MRI.triggerCounter))
    disp('==> Please don''t forget to close the trigger counter programm manually! <==');
    disp('    First press ESC to stop the program execution and after that close');
    disp('    the command window.');
end
