function [] = destroyPtGryTrackers
% function [] = destroyPtGryTrackers
%
% This function destroys all point grey trackers
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% Author:   Jonas Rose
% Version:  1.0

% you can find all point grey devices this way, each must be started:
ptGry   = imaqhwinfo('pointgrey');

% destroy each point grey device
for i=1:length(ptGry)
    vin = videoinput('pointgrey', i);
    nfo = getselectedsource(vin);
    % control using memory mapped file (name is based on the serial number)
    mmFle = memmapfile([nfo.SerialNumber '_ctrl.txt'],'Format','double');
    mmFle.Writable = true;
    mmFle.Data(1) = -1;     % destroy the tracker at the end of the experiment
end
pause(5);
