function total = dotPresentationHuman(trackingAreaSize,trackingAreaSteps, stimulusSize, stimulus)
% This function is used in conversionMatrixCreator_Human to display stimuli
% in the desired tracking area and to track pecks on those stimuli.
%
% INPUTS
% * trackingAreaSize    : vector of pixels determining the size of the field on
%                         the screen in which pecks can be tracked later on [most left x pixel,
%                         most right x pixel, highest y pixel, lowest y pixel].
%                         Difference of x and y pixels needs to be dividable with
%                         trackingAreaSteps
% * trackingAreaSteps   : distance in pixels between each presented stimulus
%                         in x an y coordinates
% * stimulusSize        : stimulus size in pixel
% * stimulus            : the displayed stimulus
%
% OUTPUTS
%  * total  = cell in size of trackingAreaSize, with tracked coordinates
%             at the positions where the stimuli were shown
%
% EXAMPLES
%   total = dotPresentation([800 1200 600 800],[200], [140], whiteDot);
%   Presents the image whiteDot 140x140 sized in 200 Pixel steps between x coordinat 800 and 1200
%   and y coordinate 600 and 800.
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x



% VERSION HISTORY:
% Author:  		Dorian Roeders
% Version: 		1.0
% Last Change:  22.03.2022

% 22.03.2022, Dorian: first version

global SETUP

for x=trackingAreaSize(1):trackingAreaSteps:trackingAreaSize(2) % steps of dot on length of screen (in pixel)
    for y=trackingAreaSize(3):trackingAreaSteps:trackingAreaSize(4) % steps of dot on heigth of screen (in pixel)
        timeDifference=0;
        x2=0;
        y2=0;
        showStimuli(stimulus, 'rect',[x-stimulusSize/2 y-stimulusSize/2 x+stimulusSize/2 y+stimulusSize/2]); %specify size of dot (in pixel)
        % find current frame
        WaitSecs(4);
        firstFrm        = SETUP.tracker.bufFle{1}.Data(4);
        lastFrm         = firstFrm;
        if lastFrm < SETUP.tracker.bufFle{1}.Data(4)
            % the index of the current frame (first tracker)
            lastFrm = SETUP.tracker.bufFle{1}.Data(4);
        end
        time1=GetSecs;
        while timeDifference<5
            c1 = SETUP.tracker.bufFle{1}.Data(1); % tracked x value from camera 1
            c2 = SETUP.tracker.bufFle{2}.Data(1); % tracked x value from camera 2

            if ~isnan(c1) && ~isnan(c2)% an object is tracked
                for i=1:2
                    if i == 1 % camera 1
                        x2 = c1; % x value = tracked value from camera 1
                    else % camera 2
                        y2 = c2; % y value = tracked value from camera 2
                    end
                end
            end
            timeDifference=GetSecs-time1;
        end
        res{y,x}=[x2 y2];

        showStimuli();

    end
end
total=res;
closeWindow;
end