function [] = frameAcquired_Arena(vid,~,vTrck)
% function [] = frameAcquired(vid,~,vTrck)
%
% Callback function for head tracking
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Author : Jonas Rose
% Version: 1.3
%
% Modifications:
% Feb 05 2018 : Jonas   : added control/ destroy
% Sep 25 2018 : Jonas   : added dark/light backgound options (obj.trckWhite)
% Sep 26 2018 : Jonas   : added option to store 'raw' data
% Jul .. 2021 : Sara    : added tracking mask
% Aug 03 2021 : Aylin   : added option to track black and white
%                         simulatenously
% Aug 09 2021 : Aylin   : modified for simultaneous black/white tracking
% Aug 15 2021 : Aylin   : corrected number of columns (from 7 to 10), necessary
%                         due to modified mmf 'datOutHand' ('*_dat.txt') now
%                         with 8 columns [xB,yB,angB,xW,yW,angW,frame#,time],
%                         bin file accordingly with 10 columns


%% callback function for each camera frame

% color of target object set via user selection
if strcmp(vTrck.trckCol,'black')        % target object color = black
    % threshold the frame and do the blob-analysis
    vTrck.blobHand.MinimumBlobArea = vTrck.blobSizeB; % use blob min of black target
    [ctrB, angB] = step(vTrck.blobHand, sum(getdata(vid,1),3)<vTrck.blobThresholdB & vTrck.mask);
    ctrW = [];

elseif strcmp(vTrck.trckCol,'white')	% vTrck.trckCol == 2 % target object color = white
    % threshold the frame and do the blob-analysis
    vTrck.blobHand.MinimumBlobArea = vTrck.blobSizeW; % use blob min of white target
    [ctrW, angW] = step(vTrck.blobHand, sum(getdata(vid,1),3)>vTrck.blobThresholdW & vTrck.mask);
    ctrB = [];

elseif strcmp(vTrck.trckCol,'both')     % target object color = both (black + white) % ALTERNATIVE: 'else'
    % threshold the frame and do the blob-analysis: black target object
    vTrck.blobHand.MinimumBlobArea = vTrck.blobSizeB; % use blob min of black target
    [ctrB, angB] = step(vTrck.blobHand, sum(getdata(vid,1),3)<vTrck.blobThresholdB & vTrck.mask);
    % threshold the frame and do the blob-analysis: white target object
    vTrck.blobHand.MinimumBlobArea = vTrck.blobSizeW; % use blob min of white target
    [ctrW, angW] = step(vTrck.blobHand, sum(getdata(vid,1),3)>vTrck.blobThresholdW & vTrck.mask);
end

if isempty(ctrB) % if only white target
    ctrB = [nan nan];
    angB = nan;
end

if isempty(ctrW) % if only black target
    ctrW = [nan nan];
    angW = nan;
end

% write to memory mapped file [x y angle x y angle frameNr time]
% first 'x,y,angle' for black target, second 'x,y,angle' for white target (nan if missing)
vTrck.datOutHand.Data = [ctrB(1), ctrB(2), angB, ctrW(1),ctrW(2),angW, vTrck.datOutHand.Data(7)+1, GetSecs];

% check if the command to write data to file were given
if vTrck.savData && vTrck.datInHand.Data(2)~=-1
    fwrite(vTrck.savDatFle, ...
        [vTrck.datInHand.Data(3),vTrck.datInHand.Data(4),... % space for event codes
        ctrB(1),ctrB(2),angB, ... % black target object
        ctrW(1),ctrW(2),angW, ... % white target object
        vTrck.datOutHand.Data(7), vTrck.datOutHand.Data(8)],'double'); % frame ID and time
end

% check if the command to stop and destroy the player was given
if vTrck.datInHand.Data(1)==-1
    % maybe close data-file
    if vTrck.datInHand.Data(2)~=-1
        fclose(vTrck.datInHand.Data(2));
    end
    % reset
    vTrck.datInHand.Data(1) = 0;
    destroy(vTrck);
end
