function [] = frameAcquired_Box(vid,~,vTrck)
% function [] = frameAcquired_Box(vid,~,vTrck)
%
% Callback function for head tracking
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Author : Jonas Rose
% Version: 1.3

% Feb 05 2018 : Jonas   : added control/ destroy
% Sep 25 2018 : Jonas   : added dark/light backgound options (obj.trckWhite)
% Sep 26 2018 : Jonas   : added option to store 'raw' data
% Oct 05 2021 : Dorian  : tracks without blob, finds median of tracked
%                         values, only used for Skinner box beak tracking
%% callback function for each camera frame
ang=0;
ctr(2)=0;

% invert logic for white/ balck background
if strcmp(vTrck.trckCol,'white')
    % threshold the frame and check for median x value of tracked object
    mat=sum(sum(getdata(vid,1),3)>vTrck.blobThresholdW & vTrck.mask);
    ctr(1)=round(median(find(mat)));
else
    mat=sum(sum(getdata(vid,1),3)<vTrck.blobThresholdB & vTrck.mask);
    ctr(1)=round(median(find(mat)));
end

% no output received (for whatever reason)
if isempty(ctr)
    ctr = [nan nan nan nan];
    ang = nan;
end

% write to memory mapped file [x y angle frameNr time]
vTrck.datOutHand.Data = [ctr(1,1),ctr(1,2),0,0,ang,0, vTrck.datOutHand.Data(7)+1, GetSecs];


% % check if the command to write data to file were given
if vTrck.savData && vTrck.datInHand.Data(2)~=-1
    fwrite(vTrck.savDatFle, ...
        [vTrck.datInHand.Data(3),vTrck.datInHand.Data(4), ctr(1,1),ctr(1,2),ang, ...
        vTrck.datOutHand.Data(4), vTrck.datOutHand.Data(5)],'double');
end


% check if the command to stop and destroy the player was given
if vTrck.datInHand.Data(1)==-1
    % maybe close data-file
    if vTrck.datInHand.Data(2)~=-1
        fclose(vTrck.datInHand.Data(2));
    end
    % reset
    vTrck.datInHand.Data(1) = 0;
    destroy(vTrck);
end
