function [x, y, buttons] = getMouseTracking
% Function that imiatates the getMouse function to be used with camera
% tracking. Needs tracker output and conversion matrix.
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% VERSION HISTORY:
% Author:  		Dorian Roeders, Farina Lingstaedt
% Version: 		1.1
% Last Change:  25.03.2022

% 30.11.2021, Dorian, Farina: first version
% 25.03.2022, Tobias: removed input argument (not used)

% set values for x and y to zero
global SETUP

x = 0;
y = 0;

% set buttons to false
buttons = false;

% find current frame
firstFrm        = SETUP.tracker.bufFle{1}.Data(4);
lastFrm         = firstFrm;

if lastFrm < SETUP.tracker.bufFle{1}.Data(4)
    % the index of the current frame (first tracker)
    lastFrm = SETUP.tracker.bufFle{1}.Data(4);
end

% loop through both cameras
for i = 1:2
    if ~isnan(SETUP.tracker.bufFle{1}.Data(1)) % an object is tracked
        buttons = true;
        if i == 1 % camera 1
            x = SETUP.tracker.bufFle{1}.Data(1); % x value = tracked value from camera 1
        else % camera 2
            y = SETUP.tracker.bufFle{2}.Data(1); % y value = tracked value from camera 2
        end

        if i == 2 % values were obtained from both cameras
            a = (SETUP.trackerConversionMatrix1>(x-5)) & (SETUP.trackerConversionMatrix1<(x+5)); % find value close to x in conversion matrix for camera 1
            b = (SETUP.trackerConversionMatrix2>(y-5)) & (SETUP.trackerConversionMatrix2<(y+5)); % find value close to y in conversion matrix for camera 2
            c=a+b; % combine both
            [rows,cols] = find(c == 2); %find position of pixel in which both cameras tracked an object

            if isempty(rows) || isempty(cols) % nothing was trakced
                x = 0;
                y = 0;
                buttons = false;
            else
                x = mean(cols)*10; % x value as getMouse output
                y = mean(rows)*10; % y value as getMouse output

            end
        end
    end
end
