function matrixCalculation(calibrationResults,row, col,val)
% This function is used in conversionMatrixCreator_Human and conversionMatrixCreator_Birds
% to process the resulting tracking data in a way that it can be used later
% by getMouseTracking
%
% INPUTS
% * calibrationResults    : output from dotPresentationBirds or
%                           dotPresentationHuman
% *row                    : output from  conversionMatrixCreator_Birds.m or
%                           conversionMatrixCreator_Human.m
% *col                    : output from  conversionMatrixCreator_Birds.m or
%                           conversionMatrixCreator_Human.m
% *val                    : output from  conversionMatrixCreator_Birds.m or
%                           conversionMatrixCreator_Human.m
%
% OUTPUTS
%  * total  = ConversionMatrices C1 and C2
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% VERSION HISTORY:
% Author:  		Dorian Roeders
% Version: 		1.1
% Last Change:  25.03.2022

% 22.03.2022, Dorian: first version
% 25.03.2022, Tobias: changed header

%% create conversion matrix with the values at hand

% predefine one matrix per camera:
matC1 = zeros(size(calibrationResults)); % camera 1
matC2 = zeros(size(calibrationResults)); % camera 2

% predefined matrices are again the size of thwe screen in pixel. Fill in
% values on positions where the dot was tracked:
for i = 1:length(row)

    c = col(i); % columm
    r = row(i); % row

    matC1(r,c) = val(i,1); % value of each position in camera 1
    matC2(r,c) = val(i,2); % value of each position in camrea 2

end

%% fill in blank spots in conversion matrix

% helpers to loop through / find all nessecary values
counter = size(matC1);
a       = 0;
b       = 0;
k       = 1;
i       = 1;
c       = 0;
j       = 0;

% start with camera 1

% fill in the values missing going through each row
for k=1:counter(1) % rows
    for i=1:counter(2) % columns

        if  matC1(k,i)~=0 % find unempty field
            i=i+1;
            if i>counter(2)
                break
            end
            while  matC1(k,i)==0 && i~=counter(2) % count through all following empty fields
                a=a+1;
                b=b+1;
                c=c+1;
                i=i+1;

            end
            if a~=0
                d=(matC1(k,i)-matC1(k,i-a-1))/(a+1); % calculate value to be added in each subsequent empty field

                for j=1:b
                    matC1(k,i-a)= matC1(k,i-c-1)+d*j; % add increasing multiplications of d in each step
                    a=a-1;
                end
                j=0;
            end
        end
        a=0;
        b=0;
        c=0;
    end

end

% fill in the values missing going through each column
for i=1:counter(2) % columns
    for k=1:counter(1) % rows

        if  matC1(k,i)~=0 % find unempty field
            k=k+1;
            if k>counter(1)
                break
            end
            while  matC1(k,i)==0 && k~=counter(1) %count through all following empty fields
                a=a+1;
                b=b+1;
                c=c+1;
                k=k+1;

            end
            if a~=0
                d=(matC1(k,i)-matC1(k-a-1,i))/(a+1);  % calculate value to be added in each subsequent empty field

                for j=1:b
                    matC1(k-a,i)= matC1(k-c-1,i)+d*j;  % add increasing multiplications of d in each step
                    a=a-1;
                end
                j=0;
            end
        end
        a=0;
        b=0;
        c=0;
    end

end


% continue with camera 2

% fill in the values missing going through each row
for k=1:counter(1) % rows
    for i=1:counter(2) % columns

        if  matC2(k,i)~=0 % find unempty field
            i=i+1;
            if i>counter(2)
                break
            end
            while  matC2(k,i)==0 && i~=counter(2) % count through all following empty fields
                a=a+1;
                b=b+1;
                c=c+1;
                i=i+1;

            end
            if a~=0
                d=(matC2(k,i)-matC2(k,i-a-1))/(a+1); % calculate value to be added in each subsequent empty field

                for j=1:b
                    matC2(k,i-a)= matC2(k,i-c-1)+d*j; % add increasing multiplications of d in each step
                    a=a-1;
                end
                j=0;
            end
        end
        a=0;
        b=0;
        c=0;
    end

end

% fill in the values missing going through each column
for i=1:counter(2) % columns
    for k=1:counter(1) % rows

        if  matC2(k,i)~=0 % find unempty field
            k=k+1;
            if k>counter(1)
                break
            end
            while  matC2(k,i)==0 && k~=counter(1) % count through all following empty fields
                a=a+1;
                b=b+1;
                c=c+1;
                k=k+1;

            end
            if a~=0
                d=(matC2(k,i)-matC2(k-a-1,i))/(a+1); % calculate value to be added in each subsequent empty field

                for j=1:b
                    matC2(k-a,i)= matC2(k-c-1,i)+d*j; % add increasing multiplications of d in each step
                    a=a-1;
                end
                j=0;
            end
        end
        a=0;
        b=0;
        c=0;
    end

end

%% final matrix: every tenth value of original conversion matrix

% helpers to loop through / find all nessecary values
size1 = size(calibrationResults);
helper = zeros(size1(1),1);
helper(1:10:end) = 1;
endpoint = counter(2)/10;

% predefine one matrix per camera
C1 = zeros(size(calibrationResults)/10); % camera 1
C2 = zeros(size(calibrationResults)/10); % camera 2

%extract every tenth value from each original matrix
for i = 1:endpoint

    C1(:,i) = matC1(helper==1,i*10);
    C2(:,i) = matC2(helper==1,i*10);

end
save2File(C1, C2,'subject', 'ConversionMatrices');
end
