function [vT] = startPointGrey(nr,savFName)
% This is supposed to be compiled and run as .exe.
%
% Execution must be stopped and object destroyed the control memory mapped
%   file (camera serial _ctrl.txt). Set the first entry to -1 to destroy
%   object.
%
% INPUTS
%   nr : number of the point grey device, 1 if only one camera is attached.
%
% OPTIONAL
%   savFle : filename to store 'raw' data (will not save if not supplied)
%               Saving will only start if control flag is set in memory
%               mapped file (camera serial _ctrl.txt). Second entry ~= -1.
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x

% Author:   Jonas Rose
% Version:  1.0

% you can find all point grey devices this way, each must be started:
% ptgry = imaqhwinfo('pointgrey');

% default camera mode
mde = 'F7_Mono8_640x512_Mode1';

% all point grey devices
ptgry   = imaqhwinfo('pointgrey');
vT      = cell(1,length(ptgry.DeviceIDs));

% construct a videotracker for the pointgrey camera
if nargin == 2
    for i=1:length(ptgry.DeviceIDs)
        vT{i} = videoTracker('pointgrey', i, mde, savFName);
        % start the tracker
        vT{i}.start;
    end
else
    for i=1:length(ptgry.DeviceIDs)
        vT{i} = videoTracker('pointgrey', i, mde);
        % start the tracker
        vT{i}.start;
    end
end

