function out = loadVideo(filename)
% Use this function to load videos for playback in the Psych toolbox. This
% function uses GStreamer! Please make sure GStreamer is installed!
% Find more information here: http://psychtoolbox.org/docs/GStreamer
%
% Usage: out = loadVideo(filename)
%
% Example: vid = loadVideo('myTestVideo.avi');
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also: showVideo, startVideo, stopVideo, closeVideo

% Tobias Otto
% 1.2
% 22.05.2019

% 29.03.2012, Tobias: first draft
% 07.10.2013, Tobias: since we use GStreamer more video formats are allowed
% 22.05.2019, Tobias: more user info

%% Init variables
global WINDOW

%% Get file infos
[pathstr, name] = fileparts(filename);

%% Load video finally
%[ moviePtr [duration] [fps] [width] [height] [count] [aspectRatio]]=Screen('OpenMovie', windowPtr, moviefile [, async=0] [, preloadSecs=1]);
[moviePtr, duration, fps, width, height, count, aspectRatio] = Screen('OpenMovie', WINDOW.handle, filename);

%% Return struct
out.name        = name;
out.path        = pathstr;
out.filename    = filename;
out.handle      = moviePtr;
out.duration    = duration;
out.fps         = fps;
out.width       = width;
out.height      = height;
out.count       = count;
out.aspectRatio = aspectRatio;

