function startVideo(vid, varargin)
% Starts playback of a video that was loaded using loadVideo.
% After calling this function the video is not presented on the screen! Use
% showVideo in a loop to get each frame and to present it!
%
% Example 1: startVideo(vid); % Plays a video that was loaded using loadVideo
%
% Example 2: startVideo(vid, 'loop'); % Plays video in a loop
%
%
% Copyright:	Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
% Contact:      OTBR-Toolbox@ruhr-uni-bochum.de
% Source Code:  https://gitlab.ruhr-uni-bochum.de/ikn/OTBR
%
% Please cite the OTBR Toolbox where this function is used.
% Cite as:      Otto, T., Rose, J. The open toolbox for behavioral research. Behav Res (2023). 
%               https://doi.org/10.3758/s13428-023-02199-x
%
% See also: showVideo, loadVideo, stopVideo, closeVideo

% Tobias Otto
% 1.1
% 22.05.2019

% 29.03.2012, Tobias: first draft
% 22.05.2019, Tobias: added user info

%% That's all ;)
if(isempty(varargin))
    % Always start from beginning
    Screen('SetMovieTimeIndex', vid.handle, 0);
    % And go
    Screen('PlayMovie', vid.handle, 1);
elseif(strcmpi('loop', varargin{1}))
    % Start as loop
    Screen('PlayMovie', vid.handle, 1, 1);
end
